slepc-3.18.0 2022-10-01
Report Typos and Errors

# RGIsTrivial

Whether it is the trivial region (whole complex plane).

### Synopsis

    #include "slepcrg.h"
    PetscErrorCode RGIsTrivial(RG rg,PetscBool *trivial)

Not Collective

### Input Parameter

| rg | - the region context

### Output Parameter

| trivial | - true if the region is equal to the whole complex plane, e.g., an interval region with all four endpoints unbounded or an ellipse with infinite radius.

### See Also

RGCheckInside()

### Level

beginner

### Location

src/sys/classes/rg/rgbasic.c
Index of all RG routines
Table of Contents for all manual pages
Index of all manual pages